@@ -1,9 +1,15 @@
+from __future__ import annotations
+
 import threading
+from typing import TYPE_CHECKING, Iterator
 
 import pytest
 
 from pykka import ThreadingActor
 
+if TYPE_CHECKING:
+    from pykka import ActorRef
+
 
 class RegularActor(ThreadingActor):
     pass
@@ -13,21 +19,23 @@ class DaemonActor(ThreadingActor):
     use_daemon_thread = True
 
 
-@pytest.fixture
-def regular_actor_ref():
+@pytest.fixture()
+def regular_actor_ref() -> Iterator[ActorRef[RegularActor]]:
     ref = RegularActor.start()
     yield ref
     ref.stop()
 
 
-@pytest.fixture
-def daemon_actor_ref():
+@pytest.fixture()
+def daemon_actor_ref() -> Iterator[ActorRef[DaemonActor]]:
     ref = DaemonActor.start()
     yield ref
     ref.stop()
 
 
-def test_actor_thread_is_named_after_pykka_actor_class(regular_actor_ref):
+def test_actor_thread_is_named_after_pykka_actor_class(
+    regular_actor_ref: ActorRef[RegularActor],
+) -> None:
     alive_threads = threading.enumerate()
     alive_thread_names = [t.name for t in alive_threads]
     named_correctly = [
@@ -37,7 +45,9 @@ def test_actor_thread_is_named_after_pykka_actor_class(regular_actor_ref):
     assert any(named_correctly)
 
 
-def test_actor_thread_is_not_daemonic_by_default(regular_actor_ref):
+def test_actor_thread_is_not_daemonic_by_default(
+    regular_actor_ref: ActorRef[RegularActor],
+) -> None:
     alive_threads = threading.enumerate()
     actor_threads = [t for t in alive_threads if t.name.startswith("RegularActor")]
 
@@ -46,8 +56,8 @@ def test_actor_thread_is_not_daemonic_by_default(regular_actor_ref):
 
 
 def test_actor_thread_is_daemonic_if_use_daemon_thread_flag_is_set(
-    daemon_actor_ref,
-):
+    daemon_actor_ref: ActorRef[DaemonActor],
+) -> None:
     alive_threads = threading.enumerate()
     actor_threads = [t for t in alive_threads if t.name.startswith("DaemonActor")]
 
